@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -338,9 +338,13 @@ insert_html (GtkWidget *mi, GtkHTMLControlData *cd)
                 (*items)++; items_sep++
 
 #define ADD_ITEM(l,f,t) \
-		menuitem = gtk_menu_item_new_with_label (l); \
+		menuitem = gtk_menu_item_new_with_mnemonic (l); \
                 ADD_ITEM_BASE (f,t)
 
+#define ADD_ITEM_MNEMONIC(l,f,t) \
+		menuitem = gtk_menu_item_new_with_mnemonic (l); \
+		ADD_ITEM_BASE (f,t)
+
 #define ADD_STOCK(i,f) \
 		menuitem = gtk_image_menu_item_new_from_stock (i, NULL); \
                 ADD_ITEM_BASE (f,NONE);
@@ -439,11 +443,11 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 	ADD_STOCK_SENSITIVE (GTK_STOCK_CUT,  cut, active);
 	ADD_STOCK_SENSITIVE (GTK_STOCK_COPY, copy, active);
 	ADD_STOCK (GTK_STOCK_PASTE, paste);
-	ADD_ITEM (_("Paste Quotation"),  paste_cite, NONE);
+	ADD_ITEM_MNEMONIC (_("Paste _Quotation"),  paste_cite, NONE);
 
 	if (cd->format_html) {
 		ADD_SEP;
-		ADD_ITEM (_("Insert Link"), insert_link, NONE);
+		ADD_ITEM (_("Insert _Link"), insert_link, NONE);
 		if (((active && html_engine_selection_contains_link (e))
 		     || (obj
 			 && (HTML_OBJECT_TYPE (obj) == HTML_TYPE_LINKTEXT
@@ -581,8 +585,9 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 					      GTK_MENU_SHELL (menu));
 	END_SUBMENU;
 
+	g_object_ref_sink (menu);
 	if (*items == 0) {
-		g_object_ref_sink (menu);
+		g_object_unref (menu);
 		menu = NULL;
 	} else
 		gtk_widget_show (menu);
@@ -602,6 +607,9 @@ popup_show (GtkHTMLControlData *cd, GdkEventButton *event)
 		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 				event ? event->button : 0, event ? event->time : 0);
 
+	if (menu)
+		g_object_unref (menu);
+
 	return (items > 0);
 }
 
@@ -625,10 +633,13 @@ popup_show_at_cursor (GtkHTMLControlData *cd)
 	guint items, props;
 
 	menu = prepare_properties_and_menu (cd, &items, &props);
-	gtk_widget_show (menu);
+
 	if (items)
 		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, set_position, cd, 0, 0);
 
+	if (menu)
+		g_object_unref (menu);
+
 	return (items > 0);
 }
 
@@ -639,7 +650,10 @@ property_dialog_show (GtkHTMLControlData *cd)
 	guint items, props;
 
 	menu = prepare_properties_and_menu (cd, &items, &props);
-	g_object_ref_sink (menu);
+
+	if (menu)
+		g_object_unref (menu);
+
 	if (props)
 		show_prop_dialog (cd, GTK_HTML_EDIT_PROPERTY_NONE);
 }
