@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GTKHTML_H_
@@ -25,8 +25,6 @@
 #include <sys/types.h>
 #include <gtk/gtklayout.h>
 #include <gtk/gtkbindings.h>
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
 
 #include "gtkhtml-types.h"
 #include "gtkhtml-enums.h"
@@ -216,34 +214,29 @@ void                       gtk_html_set_animate                   (GtkHTML
 gboolean                   gtk_html_get_animate                   (const GtkHTML             *html);
 
 /* Printing support.  */
-void                       gtk_html_print_with_header_footer      (GtkHTML                   *html,
-								   GnomePrintContext         *print_context,
-								   gdouble                    header_height,
-								   gdouble                    footer_height,
-								   GtkHTMLPrintCallback       header_print,
-								   GtkHTMLPrintCallback       footer_print,
-								   gpointer                   user_data);
-void                       gtk_html_print                         (GtkHTML                   *html,
-								   GnomePrintContext         *print_context);
-gint                       gtk_html_print_get_pages_num           (GtkHTML                   *html,
-								   GnomePrintContext         *print_context,
-								   gdouble                    header_height,
-								   gdouble                    footer_height);
-void                       gtk_html_print_set_master              (GtkHTML                   *html,
-								   GnomePrintJob             *print_master);
-void 			   gtk_html_print_page_with_header_footer  (GtkHTML		     *html,
-								   GtkPrintContext 	     *print_context,
+void 			   gtk_html_print_page_with_header_footer (GtkHTML		     *html,
+								   GtkPrintContext 	     *context,
 			   					   gdouble		      header_height,
 								   gdouble		      footer_height,
 								   GtkHTMLPrintCallback       header_print,
 							           GtkHTMLPrintCallback       footer_print,
 								   gpointer 		      user_data);
 void			   gtk_html_print_page			   (GtkHTML		      *html,
-								    GtkPrintContext	      *print_context);
+								    GtkPrintContext	      *context);
 gint 			   gtk_html_print_page_get_pages_num 	  (GtkHTML		      *html,
-								   GtkPrintContext            *print_context,
+								   GtkPrintContext            *context,
 					 			   gdouble		       header_height,
 								   gdouble                     footer_height);
+GtkPrintOperationResult	   gtk_html_print_operation_run		  (GtkHTML                    *html,
+								   GtkPrintOperation          *operation,
+								   GtkPrintOperationAction     action,
+								   GtkWindow                  *parent,
+								   GtkHTMLPrintCalcHeight      calc_header_height,
+								   GtkHTMLPrintCalcHeight      calc_footer_height,
+								   GtkHTMLPrintDrawFunc        draw_header,
+								   GtkHTMLPrintDrawFunc        draw_footer,
+								   gpointer                    user_data,
+								   GError                    **error);
 
 /* Title.  */
 const gchar               *gtk_html_get_title                     (GtkHTML                   *html);
