@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
 */
 
@@ -1491,14 +1491,15 @@ html_engine_delete_n (HTMLEngine *e, guint len, gboolean forward)
 				return;
 			}
 		}
-		while (len != 0) {
-			if (forward)
+		if (forward) {
+			int i;
+
+			for (i = len; i > 0; i--)
 				html_cursor_forward (e->cursor, e);
-			else
-				html_cursor_backward (e->cursor, e);
-			len --;
+			html_engine_delete (e);
+		} else {
+			html_object_backspace (e->cursor->object, e->cursor, e);
 		}
-		html_engine_delete (e);
 		html_engine_unblock_selection (e);
 		html_engine_thaw (e);	
 	}
