@@ -15,8 +15,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -91,6 +91,7 @@ get_font_style_from_selection (HTMLEngine *engine)
 	return style & ~conflicts;
 }
 
+/* Return value is already html_color_ref'ed */
 static HTMLColor *
 get_color_from_selection (HTMLEngine *engine)
 {
@@ -125,9 +126,14 @@ get_color_from_selection (HTMLEngine *engine)
 GtkHTMLFontStyle
 html_engine_get_document_font_style (HTMLEngine *engine)
 {
-	g_return_val_if_fail (engine != NULL, GTK_HTML_FONT_STYLE_DEFAULT);
-	g_return_val_if_fail (HTML_IS_ENGINE (engine), GTK_HTML_FONT_STYLE_DEFAULT);
-	g_return_val_if_fail (engine->editable, GTK_HTML_FONT_STYLE_DEFAULT);
+	if (!engine)
+		return GTK_HTML_FONT_STYLE_DEFAULT;
+	
+	if (!HTML_IS_ENGINE (engine))
+		return GTK_HTML_FONT_STYLE_DEFAULT;
+	
+	if (!engine->editable)
+		return GTK_HTML_FONT_STYLE_DEFAULT;
 
 	if (html_engine_is_selection_active (engine))
 		return get_font_style_from_selection (engine);
@@ -150,6 +156,7 @@ html_engine_get_document_font_style (HTMLEngine *engine)
 	}
 }
 
+/* Return value is already html_color_ref'ed */
 HTMLColor *
 html_engine_get_document_color (HTMLEngine *engine)
 {
@@ -171,9 +178,13 @@ html_engine_get_document_color (HTMLEngine *engine)
 			gint offset;
 
 			obj = html_engine_text_style_object (engine, &offset);
-			return obj
-				? html_text_get_color_at_index (HTML_TEXT (obj), engine, g_utf8_offset_to_pointer (HTML_TEXT (obj)->text, offset) - HTML_TEXT (obj)->text)
-				: html_colorset_get_color (engine->settings->color_set, HTMLTextColor);
+			if (obj) {
+				return html_text_get_color_at_index (HTML_TEXT (obj), engine, g_utf8_offset_to_pointer (HTML_TEXT (obj)->text, offset) - HTML_TEXT (obj)->text);
+			} else {
+				HTMLColor *color = html_colorset_get_color (engine->settings->color_set, HTMLTextColor);
+				html_color_ref(color);
+				return color;
+			}
 		}
 	}
 }
@@ -235,10 +246,11 @@ html_engine_update_insertion_color (HTMLEngine *engine)
 	if (new_color && !html_color_equal (new_color, engine->insertion_color)) {
 		html_color_unref (engine->insertion_color);
 		engine->insertion_color = new_color;
-		html_color_ref (engine->insertion_color);
 		return TRUE;
 	}
 
+	if (new_color)
+		html_color_unref (new_color);
 	return FALSE;
 }
 
@@ -324,9 +336,14 @@ html_engine_set_font_style (HTMLEngine *e,
 	gboolean rv;
 	GtkHTMLFontStyle old = e->insertion_font_style;
 
-	g_return_val_if_fail (e != NULL, FALSE);
-	g_return_val_if_fail (HTML_IS_ENGINE (e), FALSE);
-	g_return_val_if_fail (e->editable, FALSE);
+	if (!e)
+		return FALSE;
+
+	if (!HTML_IS_ENGINE (e))
+		return FALSE;
+
+	if (!e->editable)
+		return FALSE;
 
 	/* printf ("and %d or %d\n", and_mask, or_mask); */
 	e->insertion_font_style &= and_mask;
