@@ -18,8 +18,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 
 */
 
@@ -66,7 +66,7 @@ struct _HTMLImageFactory {
 
 #define DA(x)
 
-HTMLImageClass html_image_class;
+static HTMLImageClass html_image_class;
 static HTMLObjectClass *parent_class = NULL;
 
 static HTMLImagePointer   *html_image_pointer_new               (const char *filename, HTMLImageFactory *factory);
@@ -316,15 +316,16 @@ html_image_real_calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed_
 
 	pixel_size = html_painter_get_pixel_size (painter);
 
-	if (o->parent && HTML_IS_CLUEFLOW (o->parent)
-	    && HTML_IS_PLAIN_PAINTER (painter) && image->alt && *image->alt) {
-		GtkHTMLFontStyle style;
-		gint lo = 0;
+	if (o->parent && HTML_IS_PLAIN_PAINTER (painter) && image->alt && *image->alt) {
+		HTMLClueFlow *cf = html_object_get_flow (o);
 
-		style = html_clueflow_get_default_font_style (HTML_CLUEFLOW (o->parent));
+		if (cf)
+			html_painter_set_font_style (painter, html_clueflow_get_default_font_style (cf));
+
+		html_painter_set_font_face (painter, NULL);
 		/* FIXME: cache items and glyphs? */
-		html_painter_calc_text_size (painter, image->alt, g_utf8_strlen (image->alt, -1), NULL, NULL, NULL, 0, &lo,
-					     style, NULL, &o->width, &o->ascent, &o->descent);
+		html_painter_calc_text_size (painter, image->alt, g_utf8_strlen (image->alt, -1),
+					     &o->width, &o->ascent, &o->descent);
 	} else {
 		width = html_image_get_actual_width (image, painter);
 		height = html_image_get_actual_height (image, painter);
@@ -349,11 +350,12 @@ draw_plain (HTMLObject *o, HTMLPainter *p, gint x, gint y, gint width, gint heig
 	HTMLEngine *e;
 
 	if (p->widget && GTK_IS_HTML (p->widget))
-		e = GTK_HTML (p->widget)->engine;
+		e = html_object_engine (o, GTK_HTML (p->widget)->engine);
 	else
 		return;
 
 	if (img->alt && *img->alt) {
+		HTMLClueFlow *cf = html_object_get_flow (o);
 
 		/* FIXME: cache items and glyphs? */
 		if (o->selected) {
@@ -368,20 +370,25 @@ draw_plain (HTMLObject *o, HTMLPainter *p, gint x, gint y, gint width, gint heig
 			html_painter_set_pen (p, &html_colorset_get_color_allocated (e->settings->color_set, p,
 										     HTMLTextColor)->color);
 		}
-		html_painter_draw_text (p, o->x + tx, o->y + ty, img->alt, g_utf8_strlen (img->alt, -1), NULL, NULL, NULL, 0, 0);
+		
+		if (cf)
+			html_painter_set_font_style (p, html_clueflow_get_default_font_style (cf));
+
+		html_painter_set_font_face (p, NULL);
+		html_painter_draw_text (p, o->x + tx, o->y + ty, img->alt, g_utf8_strlen (img->alt, -1));
 	}
 }
 
 static void
-draw_focus  (HTMLPainter *painter, GdkRectangle *box)
+draw_focus  (HTMLImage *image, HTMLPainter *painter, GdkRectangle *box)
 {
 	HTMLGdkPainter *p;
 	GdkGCValues values;
-	gchar dash [2];
+	gint8 dash_list[] = { 1, 1 };
 	HTMLEngine *e;
 
 	if (painter->widget && GTK_IS_HTML (painter->widget))
-		e = GTK_HTML (painter->widget)->engine;
+		e = html_object_engine (HTML_OBJECT (image), GTK_HTML (painter->widget)->engine);
 	else
 		return;
 
@@ -395,10 +402,8 @@ draw_focus  (HTMLPainter *painter, GdkRectangle *box)
 									  painter, HTMLTextColor)->color);
 	gdk_gc_get_values (p->gc, &values);
 
-	dash [0] = 1;
-	dash [1] = 1;
 	gdk_gc_set_line_attributes (p->gc, 1, GDK_LINE_ON_OFF_DASH, values.cap_style, values.join_style);
-	gdk_gc_set_dashes (p->gc, 2, dash, 2);
+	gdk_gc_set_dashes (p->gc, 2, dash_list, 2);
 	gdk_draw_rectangle (p->pixmap, p->gc, 0, box->x - p->x1, box->y - p->y1, box->width - 1, box->height - 1);
 	gdk_gc_set_line_attributes (p->gc, 1, values.line_style, values.cap_style, values.join_style);
 }
@@ -421,7 +426,7 @@ draw (HTMLObject *o,
 	HTMLEngine *e;
 
 	if (painter->widget && GTK_IS_HTML (painter->widget))
-		e = GTK_HTML (painter->widget)->engine;
+		e = html_object_engine (o, GTK_HTML (painter->widget)->engine);
 	else
 		return;
 
@@ -479,13 +484,13 @@ draw (HTMLObject *o,
 						o->width - 2 * hspace,
 						o->ascent + o->descent - 2 * vspace);
 		}
-		html_painter_draw_panel (painter,
-					 &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
-					 o->x + tx + hspace,
-					 o->y + ty - o->ascent + vspace,
-					 o->width - 2 * hspace,
-					 o->ascent + o->descent - 2 * vspace,
-					 GTK_HTML_ETCH_IN, 1);
+		html_painter_draw_border (painter,
+					  &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
+					  o->x + tx + hspace,
+					  o->y + ty - o->ascent + vspace,
+					  o->width - 2 * hspace,
+					  o->ascent + o->descent - 2 * vspace,
+					  HTML_BORDER_INSET, 1);
 
 		if (ip->factory)
 			pixbuf = html_image_factory_get_missing (ip->factory);
@@ -510,7 +515,7 @@ draw (HTMLObject *o,
 			rect.width = scale_width + (2 * image->border) * pixel_size;
 			rect.height = scale_height + (2 * image->border) * pixel_size;
 
-			draw_focus (painter, &rect);
+			draw_focus (image, painter, &rect);
 		}				     
 
 		return;
@@ -525,13 +530,13 @@ draw (HTMLObject *o,
 			html_painter_set_pen (painter, &image->color->color);
 		}
 		
-		html_painter_draw_panel (painter,
-					 &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
-					 base_x - image->border * pixel_size,
-					 base_y - image->border * pixel_size,
-					 scale_width + (2 * image->border) * pixel_size,
-					 scale_height + (2 * image->border) * pixel_size,
-					 GTK_HTML_ETCH_NONE, image->border);
+		html_painter_draw_border (painter,
+					  &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
+					  base_x - image->border * pixel_size,
+					  base_y - image->border * pixel_size,
+					  scale_width + (2 * image->border) * pixel_size,
+					  scale_height + (2 * image->border) * pixel_size,
+					  HTML_BORDER_SOLID, image->border);
 		
 	}
 	
@@ -547,7 +552,7 @@ draw (HTMLObject *o,
 		rect.width = scale_width + (2 * image->border) * pixel_size;
 		rect.height = scale_height + (2 * image->border) * pixel_size;
 
-		draw_focus (painter, &rect);
+		draw_focus (image, painter, &rect);
 	}
 }
 
@@ -1139,7 +1144,7 @@ html_image_factory_write_pixbuf (GtkHTMLStream *stream,
 	HTMLImagePointer *p = user_data;
 
 	/* FIXME ! Check return value */
-	gdk_pixbuf_loader_write (p->loader, buffer, size, NULL);
+	gdk_pixbuf_loader_write (p->loader, (const guchar *) buffer, size, NULL);
 }
 
 static void
@@ -1285,7 +1290,7 @@ html_image_factory_free (HTMLImageFactory *factory)
 	g_hash_table_destroy (factory->loaded_images);
 
 	if (factory->missing)
-		gdk_pixbuf_unref (factory->missing);
+		g_object_unref (factory->missing);
 
 	g_free (factory);
 }
@@ -1306,9 +1311,9 @@ html_image_pointer_new (const char *filename, HTMLImageFactory *factory)
 	retval->interests = NULL;
 	retval->factory = factory;
 	retval->stall = FALSE;
-	retval->stall_timeout = gtk_timeout_add (STALL_INTERVAL, 
-						 (GtkFunction)html_image_pointer_timeout,
-						 retval);
+	retval->stall_timeout = g_timeout_add (STALL_INTERVAL, 
+					       (GtkFunction)html_image_pointer_timeout,
+					       retval);
 	retval->animation_timeout = 0;
 	return retval;
 }
@@ -1372,7 +1377,7 @@ static void
 html_image_pointer_remove_stall (HTMLImagePointer *ip)
 {
 	if (ip->stall_timeout) {
-		gtk_timeout_remove (ip->stall_timeout);
+		g_source_remove (ip->stall_timeout);
 		ip->stall_timeout = 0;
 	}
 }
